@@ -34,8 +34,8 @@
 *  POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************/
 
-#include <cv_bridge/cv_bridge.h>
-#include <cv_bridge/rgb_colors.h>
+#include <cv_bridge/cv_bridge.hpp>
+#include <cv_bridge/rgb_colors.hpp>
 #include <boost/endian/conversion.hpp>
 #include <opencv2/imgcodecs.hpp>
 #include <opencv2/imgproc/imgproc.hpp>
@@ -714,9 +714,9 @@ CvImageConstPtr cvtColorForDisplay(
   } else if (source->encoding == "CV_8UC4") {
     source_typed->encoding = enc::BGRA8;
   } else if (source->encoding == "CV_16UC3") {
-    source_typed->encoding = enc::BGR8;
+    source_typed->encoding = enc::BGR16;
   } else if (source->encoding == "CV_16UC4") {
-    source_typed->encoding = enc::BGRA8;
+    source_typed->encoding = enc::BGRA16;
   }
 
   // If no conversion is needed, don't convert
